==> haskell-hslua-marshalling-2.3.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-marshalling.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-marshalling
version:              2.3.1
visibility:           public
id:                   hslua-marshalling-2.3.1-JCueeqDsAl64rAvJDWOXcX
key:                  hslua-marshalling-2.3.1-JCueeqDsAl64rAvJDWOXcX
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2024 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Marshalling of values between Haskell and Lua.
description:
    Provides functions to marshal values from Haskell
    to Lua, and /vice versa/.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  dc5571563267278761c73c520199652e
exposed:              True
exposed-modules:
    HsLua.Marshalling HsLua.Marshalling.Peek HsLua.Marshalling.Peekers
    HsLua.Marshalling.Push HsLua.Marshalling.Userdata

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-marshalling-2.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-marshalling-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-marshalling
hs-libraries:         HShslua-marshalling-2.3.1-JCueeqDsAl64rAvJDWOXcX
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    hslua-core-2.3.1-7tP5g9DQ4OeKdOyVI81TL5 mtl-2.2.2 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-marshalling/html/hslua-marshalling.haddock

haddock-html:         /usr/share/doc/haskell-hslua-marshalling/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-marshalling-2.3.1-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-marshalling.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-marshalling
version:              2.3.1
visibility:           public
id:                   hslua-marshalling-2.3.1-GfiIDqwLJTiFJfYGxWLaEk
key:                  hslua-marshalling-2.3.1-GfiIDqwLJTiFJfYGxWLaEk
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2024 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Marshalling of values between Haskell and Lua.
description:
    Provides functions to marshal values from Haskell
    to Lua, and /vice versa/.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  c78db044e244fafd44507e68962c8b69
exposed:              True
exposed-modules:
    HsLua.Marshalling HsLua.Marshalling.Peek HsLua.Marshalling.Peekers
    HsLua.Marshalling.Push HsLua.Marshalling.Userdata

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-marshalling-2.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-marshalling-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-marshalling
hs-libraries:         HShslua-marshalling-2.3.1-GfiIDqwLJTiFJfYGxWLaEk
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    hslua-core-2.3.1-9wBIA2gFuIxACctfhiAOUi mtl-2.2.2 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-marshalling/html/hslua-marshalling.haddock

haddock-html:         /usr/share/doc/haskell-hslua-marshalling/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
